@@ -1,13 +1,18 @@
 # -*- coding: utf-8 -*-
+
+# Copyright (c) 2013 by tzf.pyramid_yml authors and contributors <see AUTHORS file>
+#
+# This module is part of tzf.pyramid_yml and is released under
+# the MIT License (MIT): http://opensource.org/licenses/MIT
+
 import os
-import sys
 import logging
 
 from pyramid.asset import resolve_asset_spec
 from pyramid.path import package_path
 from pymlconf import ConfigManager
 
-__version__ = '0.2.0'
+__version__ = '0.3.0'
 
 
 logger = logging.getLogger(__name__)
@@ -23,33 +28,32 @@ def includeme(configurator, routing_package=None):
     settings = configurator.registry.settings
 
     # lets default it to running path
-    yml_location = settings.get('yml.location', os.getcwd())
+    yml_locations = settings.get('yml.location', os.getcwd())
 
     configurator.add_directive('config_defaults',
                                config_defaults)
 
-    configurator.config_defaults(yml_location, files=[
-                                 'config.yml',
-                                 'config.{env}.yml'.format(env=settings.get('env', 'dev'))])
+    configurator.config_defaults(yml_locations)
 
     # reading yml configuration
 
     if configurator.registry['config']:
+        config = configurator.registry['config']
         logger.debug('Yaml config created')
 
         # extend settings object
-        if 'configurator' in configurator.registry['config']:
-            _extend_settings(settings, configurator.registry['config'].configurator)
+        if 'configurator' in config and config.configurator:
+            _extend_settings(settings, config.configurator)
 
         # run include's
-        if 'include' in configurator.registry['config']:
-            _run_includemes(configurator, configurator.registry['config'].include)
+        if 'include' in config:
+            _run_includemes(configurator, config.include)
 
     # let's calla a convenience request method
     configurator.add_request_method(lambda request: request.registry['config'], name='config', property=True)
 
 
-def config_defaults(configurator, config, files=['config.yml']):
+def config_defaults(configurator, config_locations, files=['config.yml']):
     '''
         Reads and extends/creates configuration from yaml source.
 
@@ -58,20 +62,28 @@ def config_defaults(configurator, config, files=['config.yml']):
             merely add those, that were not defined already!
 
         :param pyramid.config.Configurator configurator: pyramid's app configurator
-        :param string config: yaml file locations
+        :param list config_locations: list of yaml file locations
         :param list files: list of files to include from location
     '''
 
-    # getting spec path
-    package_name, filename = resolve_asset_spec(config)
-    if not package_name:
-        path = filename
-    else:
-        __import__(package_name)
-        package = sys.modules[package_name]
-        path = os.path.join(package_path(package), filename)
+    if not isinstance(config_locations, (list, tuple)):
+        config_locations = (config_locations,)
 
-    config = ConfigManager(files=[os.path.join(path, f) for f in files])
+    env = configurator.registry.settings.get('env', 'dev')
+
+    file_paths = []
+    for location in config_locations:
+        path = _translate_config_path(location)
+        current_files = files
+        if os.path.isfile(path):
+            path, current_files = os.path.split(path)
+            current_files = [current_files]
+
+        for config_path in [os.path.join(path, f) for f in _env_filenames(current_files, env)]:
+            if os.path.isfile(config_path):
+                file_paths.append(config_path)
+
+    config = ConfigManager(files=file_paths)
 
     # we could use this method both for creating and extending. Hence the checks to not override
     if not 'config' in configurator.registry:
@@ -81,6 +93,47 @@ def config_defaults(configurator, config, files=['config.yml']):
         configurator.registry['config'] = config
 
 
+def _translate_config_path(location):
+    '''
+    Translates location into fullpath according asset specification.
+    Might be package:path for package related paths, or simply path
+
+    :param str location: resource location
+    :returns: fullpath
+
+    :rtype: str
+    '''
+
+    # getting spec path
+    package_name, filename = resolve_asset_spec(location)
+    if not package_name:
+        path = filename
+    else:
+        package = __import__(package_name)
+        path = os.path.join(package_path(package), filename)
+
+    return path
+
+
+def _env_filenames(filenames, env):
+    '''
+    Extends filenames with ennv indication of environments
+
+    :param list filenames: list of strings indicating filenames
+    :param str env: environment indicator
+
+    :returns: list of filenames extended with environment version
+    :rtype: list
+    '''
+    env_filenames = []
+    for filename in filenames:
+        filename_parts = filename.split('.')
+        filename_parts.insert(1, env)
+        env_filenames.extend([filename, '.'.join(filename_parts)])
+
+    return env_filenames
+
+
 def _extend_settings(settings, configurator_config, prefix=None):
     '''
         Extends settings dictionary with yml'settings defined in configurator: key
@@ -89,6 +142,7 @@ def _extend_settings(settings, configurator_config, prefix=None):
         :param dict configurator_config: yml defined settings
         :param str prefix: prefix for settings dict key
     '''
+
     for key in configurator_config:
         settings_key = '.'.join([prefix, key]) if prefix else key
 
